|pypi| |actions| |codecov| |downloads|

edc-pharmacy
------------

.. |pypi| image:: https://img.shields.io/pypi/v/edc-pharmacy.svg
   :target: https://pypi.python.org/pypi/edc-pharmacy

.. |actions| image:: https://github.com/clinicedc/edc-pharmacy/workflows/build/badge.svg?branch=develop
   :target: https://github.com/clinicedc/edc-pharmacy/actions?query=workflow:build

.. |codecov| image:: https://codecov.io/gh/clinicedc/edc-pharmacy/branch/develop/graph/badge.svg
   :target: https://codecov.io/gh/clinicedc/edc-pharmacy

.. |downloads| image:: https://pepy.tech/badge/edc-pharmacy
   :target: https://pepy.tech/project/edc-pharmacy
